@@ -1,14 +1,11 @@
 package Mite::Role::HasConfig;
-
-use feature ':5.10';
-use Mouse::Role;
-use Method::Signatures;
+use Mite::MyMoo -Role;
 
 has config =>
-  is            => 'ro',
-  isa           => 'Mite::Config',
+  is            => ro,
+  isa           => InstanceOf['Mite::Config'],
   lazy          => 1,
-  default       => method {
+  default       => sub {
       require Mite::Config;
       state $config = Mite::Config->new;
       return $config;
